@@ -55,9 +55,6 @@
 //#undef GDA_DISABLE_DEPRECATED
 //#include <sql-parser/gda-statement-struct-util.h> //For gda_sql_identifier_remove_quotes().
 
-#ifdef GLOM_ENABLE_MAEMO
-#include <hildonmm/note.h>
-#endif
 
 #include <sstream> //For stringstream
 
@@ -139,13 +136,9 @@ void Base_DB::handle_error(const std::exception& ex)
 {
   std::cerr << "Internal Error (Base_DB::handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
 
-#ifdef GLOM_ENABLE_MAEMO
-  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, ex.what());
-#else
   Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
   dialog.set_secondary_text(ex.what());
   //TODO: dialog.set_transient_for(*get_application());
-#endif
 
   dialog.run();
 }
@@ -1697,11 +1690,8 @@ sharedptr<const LayoutItem_Field> Base_DB::get_field_identifies_non_hidden_relat
   return result;
 }
 
-sharedptr<const UsesRelationship> Base_DB::get_portal_navigation_relationship_automatic(const sharedptr<LayoutItem_Portal>& portal, bool& navigation_main) const
+sharedptr<const UsesRelationship> Base_DB::get_portal_navigation_relationship_automatic(const sharedptr<LayoutItem_Portal>& portal) const
 {
-  //Initialize output parameters:
-  navigation_main = false;
-
   const Document* document = get_document();
 
   //If the related table is not hidden then we can just navigate to that:
@@ -1709,7 +1699,6 @@ sharedptr<const UsesRelationship> Base_DB::get_portal_navigation_relationship_au
   if(!(document->get_table_is_hidden(direct_related_table_name)))
   {
     //Non-hidden tables can just be shown directly. Navigate to it:
-    navigation_main = true;
     return sharedptr<UsesRelationship>();
   }
   else
@@ -1719,7 +1708,7 @@ sharedptr<const UsesRelationship> Base_DB::get_portal_navigation_relationship_au
     sharedptr<const LayoutItem_Field> field = get_field_is_from_non_hidden_related_record(portal);
     if(field)
     {
-      return field; //Returns the relationship part. (A relationship belonging to the portal's related table.)
+      return field; //Returns the UsesRelationship base part. (A relationship belonging to the portal's related table.)
       //sharedptr<UsesRelationship> result = sharedptr<UsesRelationship>::create();
       //result->set_relationship( portal->get_relationship() );
       //result->set_related_relationship( field->get_relationship() );
@@ -2014,14 +2003,6 @@ Glib::ustring Base_DB::get_active_layout_platform(Document* document)
   if(document)
     result = document->get_active_layout_platform();
 
-  if(result.empty())
-  {
-    //Make Glom use the special "maemo" layouts if they exist.
-    #ifdef GLOM_ENABLE_MAEMO
-    return "maemo";
-    #endif
-  }
-
   return result;
 }
 
