@@ -23,7 +23,7 @@
 
 #include <libglom/libglom_config.h>
 
-#include <libgdamm/connection.h>
+#include <libgdamm.h>
 #include <libglom/sharedptr.h>
 #include <libglom/data_structure/fieldtypes.h>
 #include <libglom/data_structure/field.h>
@@ -128,12 +128,6 @@ public:
 
   Backend* get_backend();
   const Backend* get_backend() const;
-  
-  /** Discover whether the backend can create GdaDataModels that can be iterated,
-   * by creating them with the GDA_STATEMENT_MODEL_CURSOR_FORWARD flag.
-   * If not (with sqlite, for instance), the GdaDataAccessWrapper model can provide that API, without the performance.
-   */
-  bool get_backend_supports_cursor() const;
 
   /** This method will return a SharedConnection, either by opening a new connection or returning an already-open connection.
    * When that SharedConnection is destroyed, or when SharedConnection::close() is called, then the ConnectionPool will be informed.
@@ -143,17 +137,9 @@ public:
    *
    * @throws an ExceptionConnection when the connection fails.
    */
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> connect();
-#else
-  sharedptr<SharedConnection> connect(std::auto_ptr<ExceptionConnection>& error);
-#endif
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   static sharedptr<SharedConnection> get_and_connect();
-#else
-  static sharedptr<SharedConnection> get_and_connect(std::auto_ptr<ExceptionConnection>& error);
-#endif
 
   /** This callback should show UI to indicate that work is still happening.
    * For instance, a pulsing ProgressBar.
@@ -163,11 +149,7 @@ public:
  //TODO: Add SlotProgress?
   /** Creates a new database.
    */
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   void create_database(const Glib::ustring& database_name);
-#else
-  void create_database(const Glib::ustring& database_name, std::auto_ptr<Glib::Error>& error);
-#endif
 
   /** Save a backup of the database in a tarball.
    * This backup can later be used to recreate the database,
@@ -230,6 +212,9 @@ public:
    */
   bool cleanup(const SlotProgress& slot_progress);
 
+  ///Whether to automatically shutdown the database server when Glom crashes.
+  void set_auto_server_shutdown(bool val = true);
+
   /** Change the database server's configration to allow or prevent access from
    * other users on the network.
    *
@@ -242,29 +227,13 @@ public:
    */
   virtual bool set_network_shared(const SlotProgress& slot_progress, bool network_shared = true);
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  bool add_column(const Glib::ustring& table_name, const sharedptr<const Field>& field);
-#else
-  bool add_column(const Glib::ustring& field_name, const sharedptr<const Field>& field, std::auto_ptr<Glib::Error>& error);
-#endif
+  bool add_column(const Glib::ustring& table_name, const sharedptr<const Field>& field) throw();
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  bool drop_column(const Glib::ustring& table_name, const Glib::ustring& field_name);
-#else
-  bool drop_column(const Glib::ustring& table_name, const Glib::ustring& field_name, std::auto_ptr<Glib::Error>& error);
-#endif
+  bool drop_column(const Glib::ustring& table_name, const Glib::ustring& field_name) throw();
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  bool change_column(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field);
-#else
-  bool change_column(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field, std::auto_ptr<Glib::Error>& error);
-#endif
+  bool change_column(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field) throw();
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  bool change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& fields);
-#else
-  bool change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& fields, std::auto_ptr<Glib::Error>& error);
-#endif
+  bool change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& fields) throw();
 
   /** Specify a callback that the ConnectionPool can call to get a pointer to the document.
    * This callback avoids Connection having to link to Application,
@@ -323,7 +292,7 @@ private:
   Glib::ustring m_host, m_user, m_password, m_database;
 
   FieldTypes* m_pFieldTypes;
-  bool m_show_debug_output;
+  bool m_show_debug_output, m_auto_server_shutdown;
 
 private:
 
