@@ -26,11 +26,6 @@
 #include <glom/utils_ui.h> //For bold_message()).
 #include <glom/application.h>
 
-#ifdef GLOM_ENABLE_MAEMO
-#include <glom/mode_data/box_data_details.h>
-#include <glom/window_boxholder.h>
-#include <hildonmm/program.h>
-#endif //GLOM_ENABLE_MAEMO
 
 #include <glibmm/i18n.h>
 
@@ -38,11 +33,6 @@ namespace Glom
 {
 
 Box_Data_Portal::Box_Data_Portal()
-#ifdef GLOM_ENABLE_MAEMO
-: m_maemo_appmenubutton_add(Gtk::Hildon::SIZE_AUTO, Hildon::BUTTON_ARRANGEMENT_VERTICAL),
-  m_window_maemo_details(0),
-  m_box_maemo_details(0)
-#endif
 {
   //m_Frame.set_label_widget(m_Label_Related);
   m_Frame.set_shadow_type(Gtk::SHADOW_NONE);
@@ -60,24 +50,10 @@ Box_Data_Portal::Box_Data_Portal()
   add(m_Frame);
 
   m_layout_name = "list_portal"; //Replaced by derived classes.
-
-  #ifdef GLOM_ENABLE_MAEMO
-  m_maemo_appmenubutton_add.signal_clicked().connect(
-    sigc::mem_fun(*this, &Box_Data_Portal::on_maemo_appmenubutton_add));
-  #endif //GLOM_ENABLE_MAEMO
 }
 
 Box_Data_Portal::~Box_Data_Portal()
 {
-  #ifdef GLOM_ENABLE_MAEMO
-  delete m_window_maemo_details;
-
-  if(m_box_maemo_details)
-  {
-    remove_view(m_box_maemo_details);
-    delete m_box_maemo_details;
-  }
-  #endif //GLOM_ENABLE_MAEMO
 }
 
 void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_record_primary_key_value)
@@ -118,120 +94,6 @@ void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_recor
   }
 }
 
-
-#ifdef GLOM_ENABLE_MAEMO
-void Box_Data_Portal::on_maemo_appmenubutton_add()
-{
-  if(!m_portal)
-    return;
-
-  delete m_window_maemo_details;
-
-  if(m_box_maemo_details)
-  {
-    remove_view(m_box_maemo_details);
-    delete m_box_maemo_details;
-  }
-
-  m_box_maemo_details = new Box_Data_Details();
-  add_view(m_box_maemo_details);
-  m_box_maemo_details->show_all();
-
-  m_window_maemo_details = new Window_BoxHolder(m_box_maemo_details, _("Details"));
-
-  //Let this window have the main AppMenu:
-  Hildon::Program::get_instance()->add_window(*m_window_maemo_details);
-
-  Gtk::Window* pWindow = get_app_window();
-  if(pWindow)
-    m_window_maemo_details->set_transient_for(*pWindow);
-
-  //Refresh the portal when the window is closed:
-  //TODO: Refresh the parent Details too.
-  m_window_maemo_details->signal_hide().connect(
-    sigc::mem_fun(*this, &Box_Data_Portal::on_window_maemo_details_closed));
-
-  const Glib::ustring title =
-    Glib::ustring::compose(_("New Related %1"),
-      get_title_singular());
-  m_window_maemo_details->set_title(title);
-
-  FoundSet found_set;
-  found_set.m_table_name = m_portal->get_table_used(Glib::ustring());
-  Gnome::Gda::Value related_record_primary_key_value; //null for a new record.
-  m_box_maemo_details->init_db_details(found_set,
-    get_active_layout_platform(get_document()),
-    related_record_primary_key_value);
-
-  m_box_maemo_details->do_new_record(); //Doesn't block.
-
-  //Make the new record related:
-  //TODO: This only makes sense if the primary key is not auto-generated.
-  related_record_primary_key_value =
-    m_box_maemo_details->get_primary_key_value_selected();
-  make_record_related(related_record_primary_key_value);
-
-  //Show the data in the UI:
-  m_box_maemo_details->refresh_data_from_database_with_primary_key(related_record_primary_key_value);
-
-  m_window_maemo_details->show();
-}
-
-void Box_Data_Portal::on_window_maemo_details_closed()
-{
-  //Show the new added record in the portal:
-  fill_from_database();
-}
-
-void Box_Data_Portal::on_realize()
-{
-  if(!m_portal)
-    return;
-
-  // Add an Add Related Something button to the application's AppMenu.
-  // This will be removed when the portal is hidden.
-  //TODO: Use the ustring compose thingy. murrayc.
-  //TODO: Allow the designer to specify a singluar form for tables (and portals),
-  //so we can say Add Related Something instead of Somethings: Add Related.
-  const Glib::ustring title =
-    Glib::ustring::compose(_("Add Related %1"), get_title_singular());
-  m_maemo_appmenubutton_add.set_title(title);
-  m_maemo_appmenubutton_add.set_value(_("Add related record"));
-  Application* app = Application::get_application();
-  g_assert(app);
-  if(app)
-  {
-    //TODO: Use a per-window appmenu instead,
-    //so we don't get irrelevant Add Related buttons when opening extra windows above this one.
-    Hildon::AppMenu* appmenu = app->get_maemo_appmenu();
-    g_assert(appmenu);
-    if(appmenu)
-    {
-      m_maemo_appmenubutton_add.show();
-      appmenu->append(m_maemo_appmenubutton_add);
-    }
-  }
-}
-
-void Box_Data_Portal::on_unrealize()
-{
-  // Remove the AppMenu button when the portal is no longer shown:
-  Application* app = Application::get_application();
-  g_assert(app);
-  if(app)
-  {
-    Hildon::AppMenu* appmenu = app->get_maemo_appmenu();
-    g_assert(appmenu);
-    if(appmenu)
-    {
-      m_maemo_appmenubutton_add.hide();
-      Gtk::Container* container = appmenu;
-      container->remove(m_maemo_appmenubutton_add);
-    }
-  }
-}
-#endif //GLOM_ENABLE_MAEMO
-
 bool Box_Data_Portal::init_db_details(const sharedptr<const LayoutItem_Portal>& portal, bool show_title)
 {
   m_portal = glom_sharedptr_clone(portal);
@@ -407,7 +269,7 @@ void Box_Data_Portal::on_dialog_layout_hide()
 bool Box_Data_Portal::get_has_suitable_record_to_view_details() const
 {
   Glib::ustring navigation_table_name;
-  sharedptr<const UsesRelationship> navigation_relationship;
+  sharedptr<const UsesRelationship> navigation_relationship; //Ignored.
   get_suitable_table_to_view_details(navigation_table_name, navigation_relationship);
 
   return !(navigation_table_name.empty());
@@ -422,19 +284,24 @@ void Box_Data_Portal::get_suitable_table_to_view_details(Glib::ustring& table_na
     return;
 
 
-  sharedptr<const UsesRelationship> navigation_relationship = m_portal->get_navigation_relationship_specific();
+  sharedptr<const UsesRelationship> navigation_relationship;
 
   //Check whether a relationship was specified:
   if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_AUTOMATIC)
   {
     //std::cout << "debug: decide automatically." << std::endl;
     //Decide automatically:
-    bool navigation_relationship_main = false; // no longer used
-    navigation_relationship = get_portal_navigation_relationship_automatic(m_portal, navigation_relationship_main);
-    //std::cout << "debug: auto main=" << navigation_relationship_main << ", navigation_relationship=" << (navigation_relationship ? navigation_relationship->get_name() : navigation_relationship->get_relationship()->get_name()) << std::endl;
+    navigation_relationship = get_portal_navigation_relationship_automatic(m_portal);
+    //if(navigation_relationship && navigation_relationship->get_relationship())
+    //  std::cout << "  navigation_relationship->get_relationship()=" <<  navigation_relationship->get_relationship()->get_name() << std::endl;
+    //if(navigation_relationship && navigation_relationship->get_related_relationship())
+    //  std::cout << "  navigation_relationship->get_related_relationship()=" <<  navigation_relationship->get_related_relationship()->get_name() << std::endl;
+  }
+  else
+  {
+    navigation_relationship = m_portal->get_navigation_relationship_specific();
+    //std::cout << "debug: " << G_STRFUNC << ": Using specific nav." << std::endl;
   }
-  //else
-  //  std::cout << "debug: " << G_STRFUNC << ": Using specific nav." << std::endl;
 
   const Document* document = get_document();
   if(!document)
@@ -447,14 +314,16 @@ void Box_Data_Portal::get_suitable_table_to_view_details(Glib::ustring& table_na
   // The navigation_table_name (and therefore, the table_name output parameter,
   // as well) stays empty if the navrel type was set to none.
   Glib::ustring navigation_table_name;
-  if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_AUTOMATIC)
-  {
-    navigation_table_name = directly_related_table_name;
-  }
-  else if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_SPECIFIC)
+  if(navigation_relationship)
   {
     navigation_table_name = navigation_relationship->get_table_used(directly_related_table_name);
   }
+  else if(m_portal->get_navigation_type() != LayoutItem_Portal::NAVIGATION_NONE)
+  {
+    //An empty result from get_portal_navigation_relationship_automatic() or 
+    //get_navigation_relationship_specific() means we should use the directly related table:
+    navigation_table_name = directly_related_table_name;
+  }
 
   if(navigation_table_name.empty())
   {
@@ -481,6 +350,11 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   Glib::ustring navigation_table_name;
   sharedptr<const UsesRelationship> navigation_relationship;
   get_suitable_table_to_view_details(navigation_table_name, navigation_relationship);
+  
+  //if(navigation_relationship && navigation_relationship->get_relationship())
+  //  std::cout << "debug: navigation_relationship=" << navigation_relationship->get_relationship()->get_name() << std::endl;
+  //if(navigation_relationship && navigation_relationship->get_related_relationship())
+  //  std::cout << "debug: navigation_related_relationship=" << navigation_relationship->get_related_relationship()->get_name() << std::endl;
 
   if(navigation_table_name.empty())
     return;
@@ -506,7 +380,7 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   //For instance "invoice_line_id" if this is a portal to an "invoice_lines" table:
   const Glib::ustring related_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
   sharedptr<const Field> key_field = get_field_primary_key_for_table(related_table);
-  //std::cout << "DEBUG: related table=" << related_table << ", whose primary_key=" << key_field->get_name() << std::endl;
+  //std::cout << "DEBUG: related table=" << related_table << ", whose primary_key=" << key_field->get_name() << ", with value=" << primary_key_value.to_string() << "getting value for: " << layout_item->get_layout_display_name() << std::endl;
 
   Glib::RefPtr<Gnome::Gda::SqlBuilder> query = Utils::build_sql_select_with_key(related_table, fieldsToGet, key_field, primary_key_value);
   Glib::RefPtr<const Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(query);
