@@ -26,12 +26,6 @@
 #include "box_data_manyrecords.h"
 #include <glom/utility_widgets/layoutwidgetbase.h>
 
-#ifdef GLOM_ENABLE_MAEMO
-#include <hildonmm/button.h>
-//#include <glom/mode_data/box_data_details.h>
-#include <glom/window_boxholder.h>
-#endif //GLOM_ENABLE_MAEMO
-
 
 namespace Glom
 {
@@ -77,7 +71,22 @@ public:
   type_signal_portal_record_changed signal_portal_record_changed();
     
   bool get_has_suitable_record_to_view_details() const;
+
+  /** Discover what table to show when clicking on a related record.
+   * This table will not necessarily just be the directly related table.
+   *
+   * @param table_name The table that should be shown.
+   * @param relationship The relationship in the directly related table that should be used to get to that table. If this is empty then we should just show the table directly.
+   */
   void get_suitable_table_to_view_details(Glib::ustring& table_name, sharedptr<const UsesRelationship>& relationship) const;
+
+  /** Discover what record to show, in what table, when clicking on a related record.
+   * This record will not necessarily just be the directly related record.
+   *
+   * @param primary_key_value Identifies the related record that has been clicked.
+   * @param table_name The table that should be shown.
+   * @param table_primary_key_value Identifies the record in that table that should be shown.
+   */
   void get_suitable_record_to_view_details(const Gnome::Gda::Value& primary_key_value, Glib::ustring& table_name, Gnome::Gda::Value& table_primary_key_value) const;
 
 protected:
@@ -120,21 +129,6 @@ protected:
   Gnome::Gda::Value m_key_value;
     
   type_signal_portal_record_changed m_signal_portal_record_changed;
-  
-private:
-  #ifdef GLOM_ENABLE_MAEMO
-  void on_realize();
-  void on_unrealize();
-  void on_maemo_appmenubutton_add();
-  void on_window_maemo_details_closed();
-  
-  //Each related-records portal adds its own Add Something button 
-  //to the application's AppMenu when the portal is visible.
-  Hildon::Button m_maemo_appmenubutton_add;
-  
-  Window_BoxHolder* m_window_maemo_details;
-  Box_Data_Details* m_box_maemo_details;
-  #endif //GLOM_ENABLE_MAEMO
 };
 
 } //namespace Glom
