@@ -18,18 +18,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" // For GLOM_ENABLE_MAEMO
-
 #include "dialog_choose_id.h"
 #include <glom/utils_ui.h> //For bold_message()).
 //#include <libgnome/gnome-i18n.h>
 #include <glibmm/i18n.h>
 
-#ifdef GLOM_ENABLE_MAEMO
-#include <hildonmm/note.h>
-#endif
-
-
 namespace Glom
 {
 
@@ -79,10 +72,6 @@ Dialog_ChooseID::~Dialog_ChooseID()
 {
   remove_view(&m_box_find);
   remove_view(&m_box_select);
-  
-  //Work around this bug (apparently in GTK+):
-  //https://bugzilla.gnome.org/show_bug.cgi?id=660347
-  m_alignment_parent->remove();
 }
 
 void Dialog_ChooseID::setup()
@@ -113,13 +102,9 @@ void Dialog_ChooseID::on_button_quickfind()
   if(criteria.empty())
   {
     Glib::ustring message = _("You have not entered any quick find criteria.");
-#ifdef GLOM_ENABLE_MAEMO
-    Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, *this, message);
-#else
     Gtk::MessageDialog dialog(Utils::bold_message(_("No Find Criteria")), true, Gtk::MESSAGE_WARNING );
     dialog.set_secondary_text(message);
     dialog.set_transient_for(*this);
-#endif
 
     dialog.run();
   }
