@@ -19,13 +19,13 @@
  */
 
 #include "config.h"
+#include <gtkmm.h>
 #include "dialog_relationships_overview.h"
 #include "glom/utility_widgets/canvas/canvas_line_movable.h"
 #include "glom/utility_widgets/canvas/canvas_text_movable.h"
 #include <glom/mode_design/layout/dialog_choose_relationship.h>
 #include "printoperation_relationshipsoverview.h"
 #include "glom/application.h"
-#include <gtkmm/stock.h>
 #include <goocanvas.h>
 #include <glibmm/i18n.h>
 #include <iostream>
@@ -50,7 +50,7 @@ Dialog_RelationshipsOverview::Dialog_RelationshipsOverview(BaseObjectType* cobje
   m_refSettings = Gtk::PrintSettings::create();
 
   //Add a menu:
-  Gtk::VBox* vbox = 0;
+  Gtk::Box* vbox = 0;
   builder->get_widget("vbox_placeholder_menubar", vbox);
 
   m_refActionGroup = Gtk::ActionGroup::create();
@@ -71,17 +71,11 @@ Dialog_RelationshipsOverview::Dialog_RelationshipsOverview(BaseObjectType* cobje
   m_refUIManager->insert_action_group(m_refActionGroup);
   add_accel_group(m_refUIManager->get_accel_group());
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-  #endif
     static const Glib::ustring ui_description =
     "<ui>"
-#ifdef GLOM_ENABLE_MAEMO
-    "  <popup name='Overview_MainMenu'>"
-#else
     "  <menubar name='Overview_MainMenu'>"
-#endif
     "    <menu action='Overview_MainMenu_File'>"
     "      <menuitem action='Overview_MainMenu_File_PageSetup' />"
     "      <menuitem action='Overview_MainMenu_File_Print' />"
@@ -89,28 +83,15 @@ Dialog_RelationshipsOverview::Dialog_RelationshipsOverview(BaseObjectType* cobje
     "    <menu action='Overview_MainMenu_View'>"
     "      <menuitem action='Overview_MainMenu_View_Grid' />"
     "    </menu>"
-#ifdef GLOM_ENABLE_MAEMO
-    "  </popup>"
-#else
     "  </menubar>"
-#endif
     "</ui>";
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
     m_refUIManager->add_ui_from_string(ui_description);
   }
   catch(const Glib::Error& ex)
   {
     std::cerr << "building menus failed: " <<  ex.what();
   }
-  #else
-  std::auto_ptr<Glib::Error> error;
-  m_refUIManager->add_ui_from_string(ui_info, error);
-  if(error.get())
-  {
-    std::cerr << "building menus failed: " << error->what();
-  }
-  #endif
 
   //Get the menu:
   m_menu = dynamic_cast<Gtk::MenuBar*>( m_refUIManager->get_widget("/Overview_MainMenu") );
@@ -216,13 +197,12 @@ void Dialog_RelationshipsOverview::draw_tables()
       Glib::RefPtr<CanvasGroupDbTable> table_group =
         CanvasGroupDbTable::create(info->get_name(), info->get_title_or_name(), fields, table_x, table_y);
       m_group_tables->add_child(table_group);
+      m_canvas.associate_with_grid(table_group); //Make snapping work.
 
-      sigc::connection the_connection = table_group->signal_moved().connect( sigc::bind(
-        sigc::mem_fun(*this, &Dialog_RelationshipsOverview::on_table_moved),
-        table_group) );
-      m_list_table_connections.push_back(the_connection);
+      table_group->signal_moved().connect(
+        sigc::mem_fun(*this, &Dialog_RelationshipsOverview::on_table_moved));
 
-      the_connection = table_group->signal_show_context().connect( sigc::bind(
+      sigc::connection the_connection = table_group->signal_show_context().connect( sigc::bind(
         sigc::mem_fun(*this, &Dialog_RelationshipsOverview::on_table_show_context),
         table_group) );
       m_list_table_connections.push_back(the_connection);
@@ -339,8 +319,8 @@ void Dialog_RelationshipsOverview::draw_lines()
           const double text_y = ((from_field_y + to_field_y) / 2) + y_offset;
           Glib::RefPtr<CanvasTextMovable> text = CanvasTextMovable::create(relationship->get_title_or_name(),
             text_x, text_y, -1, //TODO: Calc a suitable width.
-            Gtk::ANCHOR_CENTER);
-          text->property_font() = "sans 10";
+            Goocanvas::ANCHOR_CENTER);
+          text->property_font() = "Sans 10";
           text->property_use_markup() = true;
           text->set_movement_allowed(false, false); //Move only as part of the parent group.
           m_group_lines->add_child(text);
@@ -388,12 +368,10 @@ void Dialog_RelationshipsOverview::on_menu_view_showgrid()
 {
   if(m_action_showgrid->get_active())
   {
-    std::cout << "showing" << std::endl;
     m_canvas.set_grid_gap(40);
   }
   else
   {
-    std::cout << "hiding" << std::endl;
     m_canvas.remove_grid();
   }
 }
@@ -445,8 +423,13 @@ Glib::RefPtr<CanvasGroupDbTable> Dialog_RelationshipsOverview::get_table_group(c
   return Glib::RefPtr<CanvasGroupDbTable>();
 }
 
-void Dialog_RelationshipsOverview::on_table_moved(Glib::RefPtr<CanvasGroupDbTable> table)
+void Dialog_RelationshipsOverview::on_table_moved(const Glib::RefPtr<CanvasItemMovable>& item, double /* x_offset */, double /* y_offset */)
 {
+  Glib::RefPtr<CanvasGroupDbTable> table = 
+    Glib::RefPtr<CanvasGroupDbTable>::cast_dynamic(item);
+  if(!table)
+    return;
+
   Document* document = dynamic_cast<Document*>(get_document());
   if(document && table)
   {
@@ -498,10 +481,8 @@ void Dialog_RelationshipsOverview::setup_context_menu()
   m_context_menu_uimanager = Gtk::UIManager::create();
   m_context_menu_uimanager->insert_action_group(m_context_menu_action_group);
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-  #endif
     Glib::ustring ui_info =
     "<ui>"
     "  <popup name='ContextMenu'>"
@@ -510,21 +491,12 @@ void Dialog_RelationshipsOverview::setup_context_menu()
     "  </popup>"
     "</ui>";
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
     m_context_menu_uimanager->add_ui_from_string(ui_info);
   }
   catch(const Glib::Error& ex)
   {
     std::cerr << "building menus failed: " <<  ex.what();
   }
-  #else
-  std::auto_ptr<Glib::Error> error;
-  m_context_menu_uimanager->add_ui_from_string(ui_info, error);
-  if(error.get())
-  {
-    std::cerr << "building menus failed: " << error->what();
-  }
-  #endif
 
   //Get the menu:
   m_context_menu = dynamic_cast<Gtk::Menu*>( m_context_menu_uimanager->get_widget("/ContextMenu") );
