@@ -14,11 +14,13 @@
 #include <glom/mode_data/datawidget/dialog_choose_date.h>
 #include <glom/mode_data/datawidget/dialog_choose_id.h>
 #include <glom/utility_widgets/dialog_flowtable.h>
-#include <glom/utility_widgets/dialog_image_progress.h>
+#include <glom/utility_widgets/dialog_image_load_progress.h>
+#include <glom/utility_widgets/dialog_image_save_progress.h>
 #include <glom/mode_design/layout/dialog_choose_field.h>
 #include <glom/mode_design/dialog_add_related_table.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_buttonscript.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h>
+#include <glom/mode_design/layout/layout_item_dialogs/dialog_line.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_imageobject.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_notebook.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_textobject.h>
@@ -87,7 +89,8 @@ int main(int argc, char *argv[])
   instantiate_widget<DataWidgetChildren::Dialog_ChooseID>();
   instantiate_widget<DataWidgetChildren::Dialog_ChooseDate>();
   instantiate_widget<Dialog_InvalidData>();
-  instantiate_widget<Dialog_Image_Progress>();
+  instantiate_widget<DialogImageLoadProgress>();
+  instantiate_widget<DialogImageSaveProgress>();
   instantiate_widget<Dialog_ProgressCreating>();
 
   //Developer mode UI:
@@ -110,6 +113,7 @@ int main(int argc, char *argv[])
   instantiate_widget<Box_Formatting>();
   instantiate_widget<Dialog_FieldsList>();
   instantiate_widget<Dialog_GroupBy_SortFields>();
+  instantiate_widget<Dialog_Line>();
   instantiate_widget<Dialog_ImageObject>();
   instantiate_widget<Dialog_Notebook>();
   instantiate_widget<Dialog_FieldSummary>();
